@@ -88,9 +88,7 @@ class mySql:
 		"""
 		results = self.execSelectQuery(sql, data)
 		if len(results) == 0:
-			raise Exception('empty result set returned, size = ' + str(len(results)))
-		elif len(results) != 1:
-			raise Exception('non scalar result set returned, size = ' + str(len(results)))
+			return None
 		else:	
 			return results[0][0]
 	
\ No newline at end of file
