@@ -86,7 +86,7 @@ def _insert_jos_xgroups(db, name, description):
 
 
 def _insert_jos_xgroups_members(db, gidNumber, uidNumber):
-	sql =  "INSERT INTO jos_xgroups ( gidNumber, uidNumber "
+	sql =  "INSERT INTO jos_xgroups_members(gidNumber, uidNumber) "
 	sql += "VALUES ( %s, %s );" 
 
 	data = (gidNumber, uidNumber)
