@@ -216,7 +216,7 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 		if rc:
 			print procStdErr
 		gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
-		hubzero.utilities.group._insert_jos_xgroups_members(gidNumber, userID)
+		hubzero.utilities.group._insert_jos_xgroups_members(db, gidNumber, userID)
 		
 
 	# create home directory
